``gridmeld`` Release History
============================

0.1.0 (2019-03-31)
------------------

- gate.py: Discard session object if no state key and log at level
  error.

- gate.py: ipAddresses key is optional in session object.  Fixes
  KeyError exception.  Log at level info.

- Documentation updates.

- gate.py: Fix exception usage, should be PxgridWsStompError.

0.0.0 (2018-12-08)
------------------

- First release.
